@@ -1,4 +1,5 @@
 domino_data_sources <- NULL
+netapp_volumes <- NULL
 
 .onLoad <- function(libname, pkgname) {
   py_select_interpreter()
@@ -7,4 +8,9 @@ domino_data_sources <- NULL
     "domino_data.data_sources",
     delay_load = TRUE
   )
+
+  netapp_volumes <<- reticulate::import(
+    "domino_data.netapp_volumes",
+    delay_load = TRUE
+  )
 }
